@@ -1,10 +1,10 @@
-test_that("accrual duration with specified critical values, unweighted", {
+testthat::test_that("accrual duration with specified critical values, unweighted", {
   l = lrsamplesize(beta = 0.2, kMax = 2,
                    informationRates = c(0.8, 1),
                    criticalValues = c(2.250, 2.025),
                    allocationRatioPlanned = 1,
-                   accrualTime = seq(0, 9),
-                   accrualIntensity = c(26/9*seq(1, 9), 26),
+                   accrualTime = seq(0, 8),
+                   accrualIntensity = 26/9*seq(1, 9),
                    piecewiseSurvivalTime = c(0, 6),
                    stratumFraction = c(0.2, 0.8),
                    lambda1 = c(0.0533, 0.0309, 1.5*0.0533, 1.5*0.0309),
@@ -14,20 +14,20 @@ test_that("accrual duration with specified critical values, unweighted", {
                    accrualDuration = NA,
                    followupTime = 18, fixedFollowup = FALSE,
                    rho1 = 0, rho2 = 0,
-                   numSubintervals = 300, 
+                   numSubintervals = 300,
                    rounding = 0)
-  
-  expect_equal(round(l$resultsUnderH1$overallResults$accrualDuration, 4), 
-               23.6849)
+  testthat::expect_equal(round(l$resultsUnderH1$overallResults$accrualDuration, 2),
+                         23.56)
 })
 
-test_that("accrual duration with specified critical values, weighted", {
+
+testthat::test_that("accrual duration with specified critical values, weighted", {
   l = lrsamplesize(beta = 0.2, kMax = 2,
                    informationRates = c(0.8, 1),
                    criticalValues = c(2.250, 2.025),
                    allocationRatioPlanned = 1,
-                   accrualTime = seq(0, 9),
-                   accrualIntensity = c(26/9*seq(1, 9), 26),
+                   accrualTime = seq(0, 8),
+                   accrualIntensity = 26/9*seq(1, 9),
                    piecewiseSurvivalTime = c(0, 6),
                    stratumFraction = c(0.2, 0.8),
                    lambda1 = c(0.0533, 0.0309, 1.5*0.0533, 1.5*0.0309),
@@ -39,19 +39,19 @@ test_that("accrual duration with specified critical values, weighted", {
                    rho1 = 0, rho2 = 1,
                    numSubintervals = 300,
                    rounding = 0)
-  
-  expect_equal(round(l$resultsUnderH1$overallResults$accrualDuration, 4), 
-               16.7915)
+  testthat::expect_equal(round(l$resultsUnderH1$overallResults$accrualDuration, 2),
+                         16.74)
 })
 
-test_that("accrual duration with alpha-spending, weighted", {
+
+testthat::test_that("accrual duration with alpha-spending, weighted", {
   l = lrsamplesize(beta = 0.2, kMax = 2,
                    informationRates = c(0.8, 1),
                    alpha = 0.025, typeAlphaSpending = "user",
                    userAlphaSpending = c(0.01, 0.025),
                    allocationRatioPlanned = 1,
-                   accrualTime = seq(0, 9),
-                   accrualIntensity = c(26/9*seq(1, 9), 26),
+                   accrualTime = seq(0, 8),
+                   accrualIntensity = 26/9*seq(1, 9),
                    piecewiseSurvivalTime = c(0, 6),
                    stratumFraction = c(0.2, 0.8),
                    lambda1 = c(0.0533, 0.0309, 1.5*0.0533, 1.5*0.0309),
@@ -63,13 +63,12 @@ test_that("accrual duration with alpha-spending, weighted", {
                    rho1 = 0, rho2 = 1,
                    numSubintervals = 300,
                    rounding = 0)
-  
-  expect_equal(round(l$resultsUnderH1$overallResults$accrualDuration, 4), 
-               16.7212)
+  testthat::expect_equal(round(l$resultsUnderH1$overallResults$accrualDuration, 2),
+                         16.67)
 })
 
 
-test_that("accrual duration with beta-spending, weighted", {
+testthat::test_that("accrual duration with beta-spending, weighted", {
   l = lrsamplesize(beta = 0.2, kMax = 2,
                    informationRates = c(0.8, 1),
                    alpha = 0.025, typeAlphaSpending = "user",
@@ -77,8 +76,8 @@ test_that("accrual duration with beta-spending, weighted", {
                    typeBetaSpending = "user",
                    userBetaSpending = c(0.1, 0.2),
                    allocationRatioPlanned = 1,
-                   accrualTime = seq(0, 9),
-                   accrualIntensity = c(26/9*seq(1, 9), 26),
+                   accrualTime = seq(0, 8),
+                   accrualIntensity = 26/9*seq(1, 9),
                    piecewiseSurvivalTime = c(0, 6),
                    stratumFraction = c(0.2, 0.8),
                    lambda1 = c(0.0533, 0.0309, 1.5*0.0533, 1.5*0.0309),
@@ -90,13 +89,12 @@ test_that("accrual duration with beta-spending, weighted", {
                    rho1 = 0, rho2 = 1,
                    numSubintervals = 300,
                    rounding = 0)
-  
-  expect_equal(round(l$resultsUnderH1$overallResults$accrualDuration, 4), 
-               16.9910)
+  testthat::expect_equal(round(l$resultsUnderH1$overallResults$accrualDuration, 2),
+                         16.94)
 })
 
 
-test_that("accrual duration with user-specified alpha and beta spending", {
+testthat::test_that("accrual duration with user-specified alpha and beta spending", {
   l = lrsamplesize(beta=0.1, kMax=3,
                    informationRates=c(0.5, 0.75, 1),
                    alpha=0.025, typeAlphaSpending = "user",
@@ -114,19 +112,18 @@ test_that("accrual duration with user-specified alpha and beta spending", {
                    rho1 = 0, rho2 = 0,
                    numSubintervals = 300,
                    rounding = 0)
-  
-  expect_equal(round(l$resultsUnderH1$overallResults$accrualDuration, 4), 
-               26.2029)
+  testthat::expect_equal(round(l$resultsUnderH1$overallResults$accrualDuration, 2),
+                         26.17)
 })
 
 
-test_that("follow-up duration with specified critical values, unweighted", {
+testthat::test_that("follow-up duration with specified critical values, unweighted", {
   l = lrsamplesize(beta = 0.2, kMax = 2,
                    informationRates = c(0.8, 1),
                    criticalValues = c(2.250, 2.025),
                    allocationRatioPlanned = 1,
-                   accrualTime = seq(0, 9),
-                   accrualIntensity = c(26/9*seq(1, 9), 26),
+                   accrualTime = seq(0, 8),
+                   accrualIntensity = 26/9*seq(1, 9),
                    piecewiseSurvivalTime = c(0, 6),
                    stratumFraction = c(0.2, 0.8),
                    lambda1 = c(0.0533, 0.0309, 1.5*0.0533, 1.5*0.0309),
@@ -138,18 +135,18 @@ test_that("follow-up duration with specified critical values, unweighted", {
                    rho1 = 0, rho2 = 0,
                    numSubintervals = 300,
                    rounding = 0)
-  
-  expect_equal(round(l$resultsUnderH1$overallResults$followupTime, 4), 
-               21.7556)
+  testthat::expect_equal(round(l$resultsUnderH1$overallResults$followupTime, 2),
+                         21.43)
 })
 
-test_that("follow-up duration with specified critical values, weighted", {
+
+testthat::test_that("follow-up duration with specified critical values, weighted", {
   l = lrsamplesize(beta = 0.2, kMax = 2,
                    informationRates = c(0.8, 1),
                    criticalValues = c(2.250, 2.025),
                    allocationRatioPlanned = 1,
-                   accrualTime = seq(0, 9),
-                   accrualIntensity = c(26/9*seq(1, 9), 26),
+                   accrualTime = seq(0, 8),
+                   accrualIntensity = 26/9*seq(1, 9),
                    piecewiseSurvivalTime = c(0, 6),
                    stratumFraction = c(0.2, 0.8),
                    lambda1 = c(0.0533, 0.0309, 1.5*0.0533, 1.5*0.0309),
@@ -161,21 +158,19 @@ test_that("follow-up duration with specified critical values, weighted", {
                    rho1 = 0, rho2 = 1,
                    numSubintervals = 300,
                    rounding = 0)
-  
-  expect_equal(round(l$resultsUnderH1$overallResults$followupTime, 4), 
-               9.2312)
+  testthat::expect_equal(round(l$resultsUnderH1$overallResults$followupTime, 2),
+                         9.19)
 })
 
 
-
-test_that("follow-up duration with alpha-spending, weighted", {
+testthat::test_that("follow-up duration with alpha-spending, weighted", {
   l = lrsamplesize(beta = 0.2, kMax = 2,
                    informationRates = c(0.8, 1),
                    alpha = 0.025, typeAlphaSpending = "user",
                    userAlphaSpending = c(0.01, 0.025),
                    allocationRatioPlanned = 1,
-                   accrualTime = seq(0, 9),
-                   accrualIntensity = c(26/9*seq(1, 9), 26),
+                   accrualTime = seq(0, 8),
+                   accrualIntensity = 26/9*seq(1, 9),
                    piecewiseSurvivalTime = c(0, 6),
                    stratumFraction = c(0.2, 0.8),
                    lambda1 = c(0.0533, 0.0309, 1.5*0.0533, 1.5*0.0309),
@@ -187,12 +182,12 @@ test_that("follow-up duration with alpha-spending, weighted", {
                    rho1 = 0, rho2 = 1,
                    numSubintervals = 300,
                    rounding = 0)
-  
-  expect_equal(round(l$resultsUnderH1$overallResults$followupTime, 4), 
-               9.1103)
+  testthat::expect_equal(round(l$resultsUnderH1$overallResults$followupTime, 2),
+                         9.06)
 })
 
-test_that("follow-up duration with alpha and beta spending, weighted", {
+
+testthat::test_that("follow-up duration with alpha and beta spending, weighted", {
   l = lrsamplesize(beta = 0.2, kMax = 2,
                    informationRates = c(0.8, 1),
                    alpha = 0.025, typeAlphaSpending = "sfKD",
@@ -200,8 +195,8 @@ test_that("follow-up duration with alpha and beta spending, weighted", {
                    typeBetaSpending = "sfHSD",
                    parameterBetaSpending = -2,
                    allocationRatioPlanned = 1,
-                   accrualTime = seq(0, 9),
-                   accrualIntensity = c(26/9*seq(1, 9), 26),
+                   accrualTime = seq(0, 8),
+                   accrualIntensity = 26/9*seq(1, 9),
                    piecewiseSurvivalTime = c(0, 6),
                    stratumFraction = c(0.2, 0.8),
                    lambda1 = c(0.0533, 0.0309, 1.5*0.0533, 1.5*0.0309),
@@ -213,10 +208,7 @@ test_that("follow-up duration with alpha and beta spending, weighted", {
                    rho1 = 0, rho2 = 1,
                    numSubintervals = 300,
                    rounding = 0)
-  
-  expect_equal(round(l$resultsUnderH1$overallResults$followupTime, 4), 
-               10.9929)
+  testthat::expect_equal(round(l$resultsUnderH1$overallResults$followupTime, 2),
+                         10.94)
 })
 
-
-
